@@ -467,7 +467,6 @@ g_usb_device_sync_transfer_cb (GUsbDevice *device,
 {
 	helper->ret = (*helper->finish_func) (device, res, helper->error);
 	g_main_loop_quit (helper->loop);
-	g_main_loop_unref (helper->loop);
 }
 
 /**
@@ -512,6 +511,7 @@ g_usb_device_control_transfer	(GUsbDevice	*device,
 {
 	GUsbSyncHelper helper;
 
+	helper.ret = -1;
 	helper.loop = g_main_loop_new (NULL, FALSE);
 	helper.error = error;
 	helper.finish_func = g_usb_device_control_transfer_finish;
@@ -530,6 +530,7 @@ g_usb_device_control_transfer	(GUsbDevice	*device,
 					     (GAsyncReadyCallback) g_usb_device_sync_transfer_cb,
 					     &helper);
 	g_main_loop_run (helper.loop);
+	g_main_loop_unref (helper.loop);
 
 	if (actual_length != NULL)
 		*actual_length = (gsize) helper.ret;
@@ -571,6 +572,7 @@ g_usb_device_bulk_transfer	(GUsbDevice	*device,
 {
 	GUsbSyncHelper helper;
 
+	helper.ret = -1;
 	helper.loop = g_main_loop_new (NULL, FALSE);
 	helper.error = error;
 	helper.finish_func = g_usb_device_bulk_transfer_finish;
@@ -584,6 +586,7 @@ g_usb_device_bulk_transfer	(GUsbDevice	*device,
 					  (GAsyncReadyCallback) g_usb_device_sync_transfer_cb,
 					  &helper);
 	g_main_loop_run (helper.loop);
+	g_main_loop_unref (helper.loop);
 
 	if (actual_length != NULL)
 		*actual_length = (gsize) helper.ret;
@@ -625,6 +628,7 @@ g_usb_device_interrupt_transfer	(GUsbDevice	*device,
 {
 	GUsbSyncHelper helper;
 
+	helper.ret = -1;
 	helper.loop = g_main_loop_new (NULL, FALSE);
 	helper.error = error;
 	helper.finish_func = g_usb_device_interrupt_transfer_finish;
@@ -638,6 +642,7 @@ g_usb_device_interrupt_transfer	(GUsbDevice	*device,
 					       (GAsyncReadyCallback) g_usb_device_sync_transfer_cb,
 					       &helper);
 	g_main_loop_run (helper.loop);
+	g_main_loop_unref (helper.loop);
 
 	if (actual_length != NULL)
 		*actual_length = helper.ret;
