@@ -114,7 +114,7 @@ struct _GUsbDeviceClass
 	 * If adding fields to this struct, remove corresponding
 	 * amount of padding to avoid changing overall struct size
 	 */
-	gchar _gusb_reserved[GUSB_RESERVED_PADDING];
+	gchar _gusb_reserved[G_USB_RESERVED_PADDING];
 };
 
 GType			 g_usb_device_get_type		(void);
@@ -137,6 +137,9 @@ gboolean		 g_usb_device_open		(GUsbDevice	*device,
 gboolean		 g_usb_device_close		(GUsbDevice	*device,
 							 GError		**error);
 
+gboolean		 g_usb_device_reset		(GUsbDevice	*device,
+							 GError		**error);
+
 gint			 g_usb_device_get_configuration (GUsbDevice	*device,
 							 GError		**error);
 gboolean		 g_usb_device_set_configuration (GUsbDevice	*device,
